@@ -2,7 +2,7 @@ import dataclasses
 import enum
 import fractions
 import importlib.resources
-from typing import NamedTuple
+from typing import NamedTuple, Union
 import warnings
 
 import numpy as np
@@ -16,7 +16,7 @@ from . import units
 #===============================================================================
 TRUE_VALUES = ['T']
 FALSE_VALUES = ['F']
-NA_VALUES = ['–']
+NA_VALUES = ['\N{EN DASH}']
 
 
 class SteelError(Exception):
@@ -106,19 +106,38 @@ class SteelMaterial():
             else:
                 return str(input).casefold()
 
-        material = MATERIALS_US.loc[normalize(name),
-                                    normalize(grade),
-                                    normalize(application)]
-        if len(material) != 1:
-            raise ValueError('Multiple materials found: specify grade '
-                             'and/or application to narrow search')
-        return cls(name, **material.iloc[0])
+        material = cls._get_materials_db().loc[normalize(name),
+                                               normalize(grade),
+                                               normalize(application)]
 
-    @staticmethod
-    def available_materials():
+        # Lookup succeeds if we get a Series (exact indexes) or if we get a
+        # DataFrame of length 1 (one or more indexes were sliced, but still only
+        # one result returned).
+        if isinstance(material, pd.DataFrame):
+            if len(material) != 1:
+                raise ValueError('Multiple materials found: specify grade '
+                                 'and/or application to narrow search')
+            material = material.iloc[0]
+
+        name, grade, application = material.name
+        display_grade = '' if pd.isna(grade) else f' Gr. {grade}'
+        display_name = f'{name}{display_grade} ({application})'
+        return cls(display_name.title(), **material)
+
+    @classmethod
+    def available_materials(cls):
         """Return a DataFrame of the available materials, whose rows can be used
         as lookups for `from_name`."""
-        return MATERIALS_US.index.to_frame(index=False)
+        return cls._get_materials_db().index.to_frame(index=False)
+
+    @classmethod
+    def _get_materials_db(cls) -> pd.DataFrame:
+        # Delay loading the materials database until required.
+        try:
+            return cls._materials_db
+        except AttributeError:
+            cls._materials_db = _load_materials_db('steel-materials-us.csv')
+            return cls._materials_db
 
 
 def _check_deprecated_material(name, grade):
@@ -138,12 +157,9 @@ def _load_materials_db(filename):
     return material_df
 
 
-MATERIALS_US = _load_materials_db('steel-materials-us.csv')
-
-
-#==============================================================================#
-#==[ Shapes table ]============================================================#
-#==============================================================================#
+#===============================================================================
+# Shapes table
+#===============================================================================
 class ShapesTable():
     def __init__(self, data: pd.DataFrame, units: pd.Series):
         """
@@ -182,11 +198,12 @@ class ShapesTable():
             If `shape` is not found in the table; if `prop` is not found in the
             table.
         """
+        value = self.data.at[shape.casefold(), prop]
         units = self.units.get(prop)
         if units is None:
-            return self.data.at[shape, prop]
+            return value
         else:
-            return unyt.unyt_quantity(self.data.at[shape, prop], units)
+            return unyt.unyt_quantity(value, units)
 
     def get_shape(self, shape: str, include_units: bool = True):
         """
@@ -201,7 +218,7 @@ class ShapesTable():
         -------
         pd.Series
         """
-        shape_data = self.data.loc[shape].dropna()
+        shape_data = self.data.loc[shape.casefold()].dropna()
         if include_units:
             for prop, value in shape_data.items():
                 units = self.units.get(prop)
@@ -228,7 +245,7 @@ class ShapesTable():
         >>> lightest_shape(['W14X82', 'HSS4X4X1/2'])
         'HSS4X4X1/2'
         """
-        return self.data.loc[shape_list].W.idxmin()
+        return self.data.loc[pd.Series(shape_list).str.casefold()].W.idxmin()
 
     @classmethod
     def from_file(cls,
@@ -256,20 +273,24 @@ class ShapesTable():
         data = pd.read_csv(file,
                            true_values=true_values,
                            false_values=false_values,
-                           na_values=na_values).set_index('AISC_Manual_Label')
+                           na_values=na_values)
+        data.index = pd.Index(data['AISC_Manual_Label'].str.casefold(), name='')
 
         # Convert fractions to floats
         def str2frac2float(s):
             return float(sum(fractions.Fraction(i) for i in s.split()))
 
         for column in data.columns[data.dtypes == object]:
-            if column != 'Type':
+            if column not in ['AISC_Manual_Label', 'Type']:
                 notnull_data = data[column][data[column].notnull()]
                 converted_data = notnull_data.apply(str2frac2float)
                 data[column].update(converted_data)
                 data[column] = pd.to_numeric(data[column])
 
-        return cls(data, pd.Series(units))
+        data.sort_index(inplace=True)
+        units = pd.Series(units)
+        units.sort_index(inplace=True)
+        return cls(data, units)
 
 
 _SHAPES_US_FILE = 'aisc-shapes-database-v15-0-US.csv.bz2'
@@ -487,9 +508,9 @@ def lightest_shape(shape_list):
     return shapes_US.lightest_shape(shape_list)
 
 
-#==============================================================================#
-#==[ Design ]==================================================================#
-#==============================================================================#
+#===============================================================================
+# Design
+#===============================================================================
 class MemberType(enum.Enum):
     BRACE = 'BRACE'
     BEAM = 'BEAM'
@@ -510,8 +531,8 @@ class WtrResults(NamedTuple):
 
 
 def check_seismic_wtr_wide_flange(shape: str,
-                                  mem_type: MemberType,
-                                  level: Ductility,
+                                  mem_type: Union[str, MemberType],
+                                  level: Union[str, Ductility],
                                   Ca: float,
                                   material: SteelMaterial = None) -> WtrResults:
     """Check the width-to-thickness ratio of a W shape for the given ductility.
@@ -525,7 +546,7 @@ def check_seismic_wtr_wide_flange(shape: str,
     level : Ductility
         Level of Ductility being checked.
     Ca : float
-        = P_u / (phi_c * P_y); adjusts maximum web width-to-thickness ratio
+        = P_u / (φ_c * P_y); adjusts maximum web width-to-thickness ratio
         for beams and columns. Does not affect braces. Should be < 1.0.
     material : SteelMaterial, optional
         Material to use (default A992, Fy = 50 ksi)
@@ -547,38 +568,57 @@ def check_seismic_wtr_wide_flange(shape: str,
     ---------
     AISC 341-16, Table D1.1 (pp. 9.1-14 -- 9.1-17)
     """
+    if isinstance(mem_type, MemberType):
+        mem_type: str = mem_type.value
+    if isinstance(level, Ductility):
+        level: str = level.value
+    wtr_max = {
+        ('BRACE', 'MODERATE'): _wtr_brace,
+        ('BRACE', 'HIGH'): _wtr_brace,
+        ('COLUMN', 'MODERATE'): _wtr_beam_column_moderate,
+        ('COLUMN', 'HIGH'): _wtr_beam_column_high,
+        ('BEAM', 'MODERATE'): _wtr_beam_column_moderate,
+        ('BEAM', 'HIGH'): _wtr_beam_column_high,
+    }[mem_type, level]
+
     if material is None:
         material = SteelMaterial.from_name('A992')
+    E_eFy = np.sqrt(material.E/material.eFy).to_value('dimensionless')
 
     ht = property_lookup(shape, 'h/tw')
     bt = property_lookup(shape, 'bf/2tf')
-
-    common_root = np.sqrt(material.E/material.eFy).to_value('dimensionless')
-
-    if mem_type == MemberType.BRACE:
-        ht_max = 1.57*common_root
-        bt_max = ht_max
-    elif mem_type == MemberType.BEAM or mem_type == MemberType.COLUMN:
-        if level == Ductility.MODERATE:
-            bt_max = 0.40*common_root
-            if Ca <= 0.114:
-                ht_max = 3.96*common_root*(1 - 3.04*Ca)
-            else:
-                ht_max = max(1.29*common_root*(2.12 - Ca), 1.57*common_root)
-        elif level == Ductility.HIGH:
-            bt_max = 0.32*common_root
-            if Ca <= 0.114:
-                ht_max = 2.57*common_root*(1 - 1.04*Ca)
-            else:
-                ht_max = max(0.88*common_root*(2.68 - Ca), 1.57*common_root)
-        else:
-            raise SteelError("Unsupported ductility level: {}".format(level))
-    else:
-        raise SteelError("Unsupported member type: {}".format(mem_type))
+    ht_max, bt_max = wtr_max(E_eFy, Ca)
 
     return WtrResults(ht <= ht_max and bt <= bt_max, ht, ht_max, bt, bt_max)
 
 
+def _wtr_brace(E_eFy):
+    """Maximum width-to-thickness ratio for a brace."""
+    ht_max = 1.57*E_eFy
+    bt_max = ht_max
+    return ht_max, bt_max
+
+
+def _wtr_beam_column_moderate(E_eFy, Ca):
+    """Maximum width-to-thickness ratio for a moderately ductile beam/column."""
+    bt_max = 0.40*E_eFy
+    if Ca <= 0.114:
+        ht_max = 3.96*E_eFy*(1 - 3.04*Ca)
+    else:
+        ht_max = max(1.29*E_eFy*(2.12 - Ca), 1.57*E_eFy)
+    return ht_max, bt_max
+
+
+def _wtr_beam_column_high(E_eFy, Ca):
+    """Maximum width-to-thickness ratio for a highly ductile beam/column."""
+    bt_max = 0.32*E_eFy
+    if Ca <= 0.114:
+        ht_max = 2.57*E_eFy*(1 - 1.04*Ca)
+    else:
+        ht_max = max(0.88*E_eFy*(2.68 - Ca), 1.57*E_eFy)
+    return ht_max, bt_max
+
+
 class Capacity(NamedTuple):
     tension: unyt.unyt_quantity
     compression: unyt.unyt_quantity
@@ -597,7 +637,8 @@ def brace_capacity(shape: str, length: unyt.unyt_quantity,
     material : SteelMaterial
         Brace material.
     """
-    ry = shapes_US.get_prop(shape, 'ry')
+    shape = shapes_US.get_shape(shape)
+    ry = shape['ry']
     Fe = np.pi**2*material.E/(length/ry)**2
     RyFy = material.eFy
     RyFy_Fe = RyFy/Fe
@@ -607,7 +648,7 @@ def brace_capacity(shape: str, length: unyt.unyt_quantity,
     else:
         Fcre = 0.877*Fe
 
-    Ag = shapes_US.get_prop(shape, 'A')
+    Ag = shape['A']
     tension = RyFy*Ag
     compression = min(tension, 1/0.877*Fcre*Ag)
     postbuckling = 0.3*compression
